.. _scalars:

=============================
Strings, Numbers and Booleans
=============================

.. currentmodule:: flatland.schema.scalars

Simple Fields
-------------

.. autoclass:: Scalar
   :show-inheritance:
   :members:
   :exclude-members: set_default


Strings
-------

.. autoclass:: String
   :show-inheritance:
   :members:


Numbers
-------

.. autoclass:: Number
   :show-inheritance:
   :members:


.. autoclass:: Integer
   :show-inheritance:
   :members:


.. autoclass:: Long
   :show-inheritance:
   :members:


.. autoclass:: Float
   :show-inheritance:
   :members:

.. autoclass:: Decimal
   :show-inheritance:
   :members:


Booleans
--------

.. autoclass:: Boolean
   :show-inheritance:
   :members:
